@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvd_wkvtml.cpp,v 1.13 2003/07/17 12:48:21 binner Exp $
+    $Id: kvd_wkvtml.cpp,v 1.15 2004/03/07 22:46:58 annma Exp $
 
                          write a kvtml document
 
@@ -25,14 +25,10 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "kvoctraindoc.h"
 #include "kvoctraincore.h"
 #include "QueryManager.h"
 
 #include <kdebug.h>
-#include <kapplication.h>
-#include <klocale.h>
-#include <kstandarddirs.h>
 
 #include <qtextcodec.h>
 
@@ -728,7 +724,7 @@ bool kvoctrainDoc::saveToKvtMl (QTextStream& os, QString &title) {
 
     ent_no++;
     if (ent_percent != 0 && (ent_no % ent_percent) == 0 )
-      emit progressChanged(this, ent_no / f_ent_percent);
+      emit progressChanged(this, ent_no / (int) f_ent_percent);
 
     if ((*first).getLesson() != 0) {   // entry belongs to lesson x
       QString ls;
